==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "Tidram"

, "summary"
: "Sammanfattning"

, "Total Timesheets"
: "Totala tidrapporter"

, "Billable Timesheets"
: "Debiterbara tidrapporter"

, "Total Time"
: "Total tid"

, "Time of Billable Timesheets"
: "Tid för debiterbara tidrapporter"

, "Description"
: "Beskrivning"

, "Detail"
: "Detalj"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exportera tidrapporter"

, "Export as ODS"
: "Exportera som ODS"

, "Export as CSV"
: "Exportera som CVS"

, "Export as ..."
: "Exportera som..."

, "Timesheet, Timesheets"
: [
  "Tidrapport"
 ,"Tidrapporter"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Misslyckades"

, "Could not save {0}."
: "Kunde inte spara {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Deadline för detta tidkonto har överskridits."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Kontrakt"

, "without contract"
: "utan kontrakt"

, "Add New Timeaccount"
: ""

, "Unit"
: "Enhet"

, "Unit Price"
: "Pris per enhet"

, "Factor"
: ""

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "stängd"

, "open"
: "öppen"

, "Cleared In"
: "Rensad"

, "Cleared at"
: ""

, "Cost Center"
: "Kostnadsställe"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Tidrapporter är debiterbara"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Tidkonto"
 ,"Tidkonton"

]
, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Access"
: "Tillgång"

, "Permissions"
: "Rättigheter"

, "Time Account - Billed"
: "Tidspool - Debiterad"

, "not yet billed"
: "Icke fakturerad"

, "to bill"
: "att fakturera"

, "billed"
: "fakturerad"

, "Time Account - Status"
: "Tidkonto - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Boka egen"

, "The grant to add Timesheets to this Timeaccount"
: "Möjlighet att lägga till tidrapport till detta tidkonto"

, "View All"
: "Se alla"

, "The grant to view Timesheets of other users"
: "Möjlighet att se andra användarnas tidrapporter"

, "Book All"
: "Boka alla"

, "The grant to add Timesheets for other users"
: "Möjlighet att lägga till tidrapporter för andra användare"

, "Manage Clearing"
: "Hantera rensning"

, "The grant to manage clearing of Timesheets"
: "Möjlighet att hantera rensning av tidrapporter"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Visa stängda"

, "Timesheets ODS export configuration"
: "Konfiguration för exportering av tidrapporter i ODS-format"

, "Use this configuration for the timesheet ODS export."
: "Använd denna konfiguration för exportering av tidrapporter i ODS-format."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "standard"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "ingen"

, "last week"
: "förra veckan"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Rensade i"

, "Billed"
: "Fakturerad"

, "Booking deadline"
: "Deadline för bokning"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Konto"

, "Time Account (Number - Title)"
: "Tidspool(Nummer - Titel)"

, "Billable"
: "Fakturerbar"

, "Cleared"
: "Rensad"

, "Date"
: "Datum"

, "Start time"
: "Starttid"

, "End time"
: ""

, "Duration"
: "Varaktighet"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Stängt tidkonto"

, "Timetracker"
: "Tidhanterare"

, "Timeaccounts to bill"
: "Tidkonto att fakturera"

, "Timeaccounts not yet billed"
: "Ännu ej fakturerade tidkonto"

, "Timeaccounts already billed"
: "Redan fakturerade tidkonto"

, "My Timesheets today"
: "Mina tidrapporter i dag"

, "My Timesheets this week"
: "Mina tidrapporter denna vecka"

, "My Timesheets last week"
: "Mina tidrapporter förra veckan"

, "My Timesheets this month"
: "Mina tidrapporter denna månad"

, "My Timesheets last month"
: "Mina tidrapporter förra månaden"

, "Manage timeaccounts"
: "Hantera tidkonton"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Lägg till, redigera och radera tidskonton (inklusive alla tidrapporter)"

, "Add timeaccounts"
: "Lägg till tidkonton"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Tidrapport"

, "Timeaccount"
: ""

, "Time Account"
: "Tidkonto"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "Tidram"

, "summary"
: "Sammanfattning"

, "Total Timesheets"
: "Totala tidrapporter"

, "Billable Timesheets"
: "Debiterbara tidrapporter"

, "Total Time"
: "Total tid"

, "Time of Billable Timesheets"
: "Tid för debiterbara tidrapporter"

, "Description"
: "Beskrivning"

, "Detail"
: "Detalj"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exportera tidrapporter"

, "Export as ODS"
: "Exportera som ODS"

, "Export as CSV"
: "Exportera som CVS"

, "Export as ..."
: "Exportera som..."

, "Timesheet, Timesheets"
: [
  "Tidrapport"
 ,"Tidrapporter"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Misslyckades"

, "Could not save {0}."
: "Kunde inte spara {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Deadline för detta tidkonto har överskridits."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Kontrakt"

, "without contract"
: "utan kontrakt"

, "Add New Timeaccount"
: ""

, "Unit"
: "Enhet"

, "Unit Price"
: "Pris per enhet"

, "Factor"
: ""

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "stängd"

, "open"
: "öppen"

, "Cleared In"
: "Rensad"

, "Cleared at"
: ""

, "Cost Center"
: "Kostnadsställe"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Tidrapporter är debiterbara"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Tidkonto"
 ,"Tidkonton"

]
, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Access"
: "Tillgång"

, "Permissions"
: "Rättigheter"

, "Time Account - Billed"
: "Tidspool - Debiterad"

, "not yet billed"
: "Icke fakturerad"

, "to bill"
: "att fakturera"

, "billed"
: "fakturerad"

, "Time Account - Status"
: "Tidkonto - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Boka egen"

, "The grant to add Timesheets to this Timeaccount"
: "Möjlighet att lägga till tidrapport till detta tidkonto"

, "View All"
: "Se alla"

, "The grant to view Timesheets of other users"
: "Möjlighet att se andra användarnas tidrapporter"

, "Book All"
: "Boka alla"

, "The grant to add Timesheets for other users"
: "Möjlighet att lägga till tidrapporter för andra användare"

, "Manage Clearing"
: "Hantera rensning"

, "The grant to manage clearing of Timesheets"
: "Möjlighet att hantera rensning av tidrapporter"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Visa stängda"

, "Timesheets ODS export configuration"
: "Konfiguration för exportering av tidrapporter i ODS-format"

, "Use this configuration for the timesheet ODS export."
: "Använd denna konfiguration för exportering av tidrapporter i ODS-format."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "standard"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "ingen"

, "last week"
: "förra veckan"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Rensade i"

, "Billed"
: "Fakturerad"

, "Booking deadline"
: "Deadline för bokning"

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: ""

, "Account"
: "Konto"

, "Time Account (Number - Title)"
: "Tidspool(Nummer - Titel)"

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "Fakturerbar"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "Datum"

, "Start time"
: "Starttid"

, "End time"
: ""

, "Duration"
: "Varaktighet"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: "Tidhanterare"

, "My Timesheets today"
: "Mina tidrapporter i dag"

, "My Timesheets this week"
: "Mina tidrapporter denna vecka"

, "My Timesheets last week"
: "Mina tidrapporter förra veckan"

, "My Timesheets this month"
: "Mina tidrapporter denna månad"

, "My Timesheets last month"
: "Mina tidrapporter förra månaden"

, "Timeaccounts to bill"
: "Tidkonto att fakturera"

, "Timeaccounts not yet billed"
: "Ännu ej fakturerade tidkonto"

, "Timeaccounts already billed"
: "Redan fakturerade tidkonto"

, "Manage timeaccounts"
: "Hantera tidkonton"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Lägg till, redigera och radera tidskonton (inklusive alla tidrapporter)"

, "Add timeaccounts"
: "Lägg till tidkonton"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""








, "Timesheet"
: "Tidrapport"

, "Timeaccount"
: ""

, "Time Account"
: "Tidkonto"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
